# Window


This is one of the most used subsystems.\
It handles forwarding of window contents and events.


## Implementations

| Component         | Link                                                                                                           |
|-------------------|----------------------------------------------------------------------------------------------------------------|
| client            | [xpra.client.subsystem.windows](https://github.com/Xpra-org/xpra/blob/master/xpra/client/subsystem/windows.py) |
| client connection | [xpra.server.source.windows](https://github.com/Xpra-org/xpra/blob/master/xpra/server/source/windows.py)       |
| server            | [xpra.server.subsystem.window](https://github.com/Xpra-org/xpra/blob/master/xpra/server/subsystem/window.py)   |



## Capabilities

TBD

## Network Packets

TBD
